package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.DoumuProductFjMapper;
import com.ruoyi.system.domain.DoumuProductFj;
import com.ruoyi.system.service.IDoumuProductFjService;

/**
 * 痘姆古陶_附件Service业务层处理
 * 
 * @author boman
 * @date 2024-01-16
 */
@Service
public class DoumuProductFjServiceImpl implements IDoumuProductFjService
{
    @Autowired
    private DoumuProductFjMapper doumuProductFjMapper;

    /**
     * 查询痘姆古陶_附件
     * 
     * @param fiId 痘姆古陶_附件主键
     * @return 痘姆古陶_附件
     */
    @Override
    public DoumuProductFj selectDoumuProductFjByFiId(Long fiId)
    {
        return doumuProductFjMapper.selectDoumuProductFjByFiId(fiId);
    }

    /**
     * 查询痘姆古陶_附件列表
     * 
     * @param doumuProductFj 痘姆古陶_附件
     * @return 痘姆古陶_附件
     */
    @Override
    public List<DoumuProductFj> selectDoumuProductFjList(DoumuProductFj doumuProductFj)
    {
        return doumuProductFjMapper.selectDoumuProductFjList(doumuProductFj);
    }

    /**
     * 新增痘姆古陶_附件
     * 
     * @param doumuProductFj 痘姆古陶_附件
     * @return 结果
     */
    @Override
    public int insertDoumuProductFj(DoumuProductFj doumuProductFj)
    {
        return doumuProductFjMapper.insertDoumuProductFj(doumuProductFj);
    }

    /**
     * 修改痘姆古陶_附件
     * 
     * @param doumuProductFj 痘姆古陶_附件
     * @return 结果
     */
    @Override
    public int updateDoumuProductFj(DoumuProductFj doumuProductFj)
    {
        return doumuProductFjMapper.updateDoumuProductFj(doumuProductFj);
    }

    /**
     * 批量删除痘姆古陶_附件
     * 
     * @param fiIds 需要删除的痘姆古陶_附件主键
     * @return 结果
     */
    @Override
    public int deleteDoumuProductFjByFiIds(Long[] fiIds)
    {
        return doumuProductFjMapper.deleteDoumuProductFjByFiIds(fiIds);
    }

    /**
     * 删除痘姆古陶_附件信息
     * 
     * @param fiId 痘姆古陶_附件主键
     * @return 结果
     */
    @Override
    public int deleteDoumuProductFjByFiId(Long fiId)
    {
        return doumuProductFjMapper.deleteDoumuProductFjByFiId(fiId);
    }
}
